# Generated by Django 4.2.29 on 2026-03-26 01:30

# Django
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ("eve_sde", "0018_blueprintactivity_blueprintactivityproduct_and_more"),
        ("georgeforge", "0029_alter_order_status"),
    ]

    operations = [
        migrations.AlterField(
            model_name="deliverysystem",
            name="system",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="eve_sde.solarsystem",
                verbose_name="Solar System",
            ),
        ),
        migrations.AlterField(
            model_name="forsale",
            name="eve_type",
            field=models.ForeignKey(
                limit_choices_to={"published": 1},
                on_delete=django.db.models.deletion.CASCADE,
                to="eve_sde.itemtype",
                verbose_name="EVE Type",
            ),
        ),
        migrations.AlterField(
            model_name="order",
            name="deliverysystem",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="eve_sde.solarsystem",
                verbose_name="Delivery System",
            ),
        ),
        migrations.AlterField(
            model_name="order",
            name="eve_type",
            field=models.ForeignKey(
                limit_choices_to={"published": 1},
                on_delete=django.db.models.deletion.CASCADE,
                to="eve_sde.itemtype",
                verbose_name="EVE Type",
            ),
        ),
    ]
