# Generated by Django 4.2.20 on 2025-07-25 00:11

# Django
import django.db.models.deletion
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        (
            "georgeforge",
            "0001_squashed_0020_alter_order_deposit_alter_order_paid_and_more",
        ),
    ]

    operations = [
        migrations.AlterField(
            model_name="order",
            name="deliverysystem",
            field=models.ForeignKey(
                on_delete=django.db.models.deletion.CASCADE,
                to="eveuniverse.evesolarsystem",
                verbose_name="Delivery System",
            ),
        ),
    ]
